@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: bifunctors
 version: 5.3
-id: bifunctors-5.3-b6e9a28a0175204e65003b150c0bbe80
-key: bifun_4d4FHNAJY4yLbnR9os9Tm5
+id: bifunctors-5.3-bc094c1e88d075fab4936b454b930127
+key: bifun_Ctc2G6QXpAZ6vUJm1ebeU0
 license: BSD3
 copyright: Copyright (C) 2008-2016 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -26,14 +26,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/bifunctors-5.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/bifunctors-5.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/bifunctors-5.3
-hs-libraries: HSbifunctors-5.3-4d4FHNAJY4yLbnR9os9Tm5
+hs-libraries: HSbifunctors-5.3-Ctc2G6QXpAZ6vUJm1ebeU0
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base-orphans-0.5.4-e40139ef3f9e9946a3f68f9fef66a420
-    comonad-5-3b2e208311908bc5a9db1ceb26126917
+    comonad-5-9b3bac8b2740903020c84a0c2eebf7b2
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
-    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
+    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
+    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
